<template>
  <a-card :bordered='false'>

    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>

          <a-col :lg='7' :md='8' :sm='24' :xl='6'>
            <a-form-item label='设备编号'>
              <lx-search-equipment-select v-model='queryParam.equipmentId'
                                          placeholder='请输入设备编号或名称搜索'></lx-search-equipment-select>
            </a-form-item>

          </a-col>
          <a-col :lg='7' :md='8' :sm='24' :xl='6'>
            <a-form-item label='单据号'>
              <a-input v-model='queryParam.code' placeholder='请输入单据号'></a-input>
            </a-form-item>
          </a-col>
          <template v-if='toggleSearchStatus'>
            <a-col :lg='7' :md='8' :sm='24' :xl='6'>
              <a-form-item label='调出部门'>
                <a-input v-model='queryParam.oldDepartId' placeholder='请输入调出部门'></a-input>
              </a-form-item>
            </a-col>
            <a-col :lg='7' :md='8' :sm='24' :xl='6'>
              <a-form-item label='调入部门'>
                <a-input v-model='queryParam.newDepartId' placeholder='请输入调入部门'></a-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col :lg='7' :md='8' :sm='24' :xl='6'>
            <span class='table-page-search-submitButtons' style='float: left;overflow: hidden;'>
              <a-button icon='search' type='primary' @click='searchQuery'>查询</a-button>
              <a-button icon='reload' style='margin-left: 8px' type='primary' @click='searchReset'>重置</a-button>
<!--              <a style='margin-left: 8px' @click='handleToggleSearch'>-->
<!--                {{ toggleSearchStatus ? '收起' : '展开' }}-->
<!--                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />-->
<!--              </a>-->
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button icon='plus' type='primary' @click='handleAdd'>新增</a-button>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        :columns='columns'
        :dataSource='dataSource'
        :loading='loading'
        :pagination='ipagination'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        :scroll="{ x: 'max-content' }"
        bordered
        class='j-table-force-nowrap'
        rowKey='id'
        size='middle'
        @change='handleTableChange'>

        <span slot='action' slot-scope='text, record'>
          <template v-if="record.transferStatus === 'WAIT_SUBMIT'">
              <a-popconfirm title='确定提交吗?' @confirm='() => handleSubmit(record.id)'>
              <a>提交</a>
            </a-popconfirm>
              <a-divider type='vertical' />

          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
               <a-menu-item>
                 <a @click='handleEdit(record)'>编辑</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
            </template>
          <template v-else>
            <a href='javascript:;' @click='handleDetail(record)'>详情</a>
          </template>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamEquipmentTransfer-modal ref='modalForm' @ok='modalFormOk'></eamEquipmentTransfer-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamEquipmentTransferModal from './modules/EamEquipmentTransferModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@api/manage'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'


export default {
  name: 'EamEquipmentTransferList',
  mixins: [JeecgListMixin],
  components: {
    EamEquipmentTransferModal,
    LxSearchEquipmentSelect
  },
  data() {
    return {
      description: '设备归属变动管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          fixed: 'left',
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '单据号',
          align: 'center',
          fixed: 'left',
          width: 100,
          dataIndex: 'code'
        },
        {
          title: '设备编号',
          align: 'center',
          fixed: 'left',
          width: 100,
          dataIndex: 'equipmentCode'
        },
        {
          title: '设备名称',
          align: 'center',
          fixed: 'left',
          width: 100,
          dataIndex: 'equipmentName'
        },
        {
          title: '调出部门',
          align: 'center',
          dataIndex: 'oldDepartId_dictText'
        },
        {
          title: '调入部门',
          align: 'center',
          dataIndex: 'newDepartId_dictText'
        },
        {
          title: '申请人',
          align: 'center',
          dataIndex: 'reportUser_dictText'
        },
        {
          title: '变动原因',
          align: 'center',
          dataIndex: 'transferReason'
        },
        {
          title: '变动状态',
          align: 'center',
          dataIndex: 'transferStatus_dictText'
        },
        {
          title: '变动日期',
          align: 'center',
          dataIndex: 'transferTime'
        },
        {
          title: '审核人',
          align: 'center',
          dataIndex: 'approvalUser_dictText'
        },
        {
          title: '审核意见',
          align: 'center',
          dataIndex: 'approvalComment'
        },
        {
          title: '审核时间',
          align: 'center',
          dataIndex: 'approvalTime'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 150,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/eamEquipmentTransfer/list',
        delete: '/eam/eamEquipmentTransfer/delete',
        deleteBatch: '/eam/eamEquipmentTransfer/deleteBatch',
        submit: '/eam/eamEquipmentTransfer/submit'
      }
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    handleSubmit(id) {
      if (!this.url.submit) {
        this.$message.error('请设置url.submit属性!')
        return
      }
      let that = this
      this.loading = true
      getAction(that.url.submit, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          // that.$message.success(res.message);
          that.$notification.success({
            message: '消息',
            description: res.message
          })
          that.loadData()
        } else {
          // that.$message.warning(res.message);
          that.$notification.warning({
            message: '消息',
            description: res.message
          })
        }
      }).finally(()=>{
        this.loading = false
      })
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>